spreadsheet\_wrangler package
=============================

Submodules
----------

spreadsheet\_wrangler.cli module
--------------------------------

.. automodule:: spreadsheet_wrangler.cli
   :members:
   :undoc-members:
   :show-inheritance:

spreadsheet\_wrangler.spreadsheet\_wrangler module
--------------------------------------------------

.. automodule:: spreadsheet_wrangler.spreadsheet_wrangler
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: spreadsheet_wrangler
   :members:
   :undoc-members:
   :show-inheritance:
